@@ -31,6 +31,9 @@ class Terminal:
         output_dir (str, optional): Directory for saving converted file. 
             If nothing's specified, current working directory will be used. 
             Defaults to `None`.
+        ignore_warning (dict): A dictionary to ignore and skip writing specific 
+            warning messages to the stdout. Each dictionary key stands for a 
+            warning-code, with a value of a list, containing API method names.
 
     Usage:
 
@@ -42,16 +45,11 @@ class Terminal:
         ...     input="my_document.docx"
         ...     output_format="txt-markdown"
         ... )
-    """    
+    """
 
-    silent: bool = False
-    overwrite: bool = False
-    output_dir: Optional[str] = None
-
-    app_id: str = Config.read("api", "appid")
-    security_token: str = Config.read("api", "token")
-
-    # Exit Codes
+    # Constants
+    IGNORE_ALL = "*"
+    # Exit Code Constants
     EX_SUCCESSFUL = 0
     EX_OTHER = 1
     EX_INPUT_NOT_FOUND = 2
@@ -62,39 +60,56 @@ class Terminal:
     EX_API_RESPONSE_ERROR = 7
     EX_INVALID_JSON_RESPONSE = 8
     EX_FILE_WRITE_ERROR = 9
+    EX_CONVERT_FAILED = 10
+
+    silent: bool = False
+    overwrite: bool = False
+    output_dir: Optional[str] = None
+    ignore_warning: Dict[str, list] = {
+        # Ignore all except vertopal.API.download
+        "CLI_NEW_VERSION": [
+            vertopal.API.upload.__name__,
+            vertopal.API.convert.__name__,
+            vertopal.API.status.__name__,
+            vertopal.API.task_response.__name__,
+        ],
+    }
+
+    app_id: str = Config.read("api", "appid")
+    security_token: str = Config.read("api", "token")
 
     @classmethod
     def convert(
             cls,
-            input: str,
-            input_format: Optional[str],
-            output_format: str
+            input_file: str,
+            output_format: str,
+            input_format: Optional[str] = None
     ) -> None:
         """Convert file by running upload, convert, and download tasks.
 
         Args:
-            input (str): Input file name, relative or absolute path.
-            input_format (Optional[str]): The input file `format[-type]`.
-                E.g. `txt` or `txt-markdown`. If not set, the format will be 
-                considered based on input extension.
+            input_file (str): Input file name, relative or absolute path.
             output_format (str): The output file `format[-type]`.
                 E.g. `db-docbook`.
+            input_format (Optional[str]): The input file `format[-type]`.
+                E.g. `txt` or `txt-markdown`. If not set, the format will be 
+                considered based on input extension. Defaults to `None`.
 
         Returns:
             None
         """
-        
-        filepath = Path(input).resolve()
+
+        filepath = Path(input_file).resolve()
         filename = filepath.name
         status = None
         sleep_secs = (10, 20, 30, 60)
         sleep_step = 0
 
-        cls._step("Uploading {}".format(filename), "1/4")
+        cls._step(f"Uploading {filename}", "1/4")
         upload_connector = cls._upload(filename, filepath)
 
         cls._step(
-            "Waiting for {} conversion".format(output_format.upper()),
+            f"Waiting for {output_format.upper()} conversion",
             "2/4"
         )
         convert_connector = cls._convert(
@@ -104,21 +119,36 @@ class Terminal:
         )
 
         cls._step(
-            "Converting {} to {} \u2014 please wait...".format(
-                filename,
-                output_format.upper()
-            ),
+            f"Converting {filename} to "
+            f"{output_format.upper()} \u2014 please wait...",
             "3/4"
         )
         while status != "completed":
             sleep(sleep_secs[sleep_step])
             if sleep_step < len(sleep_secs) - 1:
                 sleep_step += 1
-            status = cls._task_status(convert_connector)
+            task_response = cls._task_status(convert_connector)
+            status = task_response.task
 
-        cls._step("Downloading converted file", "4/4")
-        download = cls._download(convert_connector)
-        cls._download_file(download.connector, download.filename)
+        cls._info(f"Convert vCredits used: {task_response.vcredits}")
+
+        if task_response.convert == "failed":
+            cls._error(
+                "Conversion failed. To learn more, visit: "
+                "https://www.vertopal.com/en/help/post/27",
+                "CONVERT_FAILED",
+                end="",
+            )
+            cls.exit(cls.EX_CONVERT_FAILED)
+
+        elif task_response.convert == "successful":
+            cls._step("Downloading converted file", "4/4")
+            download = cls._download(convert_connector)
+            cls._download_file(download.connector, download.filename)
+
+        else:
+            cls._error("An unexpected error happened", end="")
+            cls.exit(cls.EX_OTHER)
 
     @classmethod
     def check_config(cls) -> None:
@@ -131,8 +161,8 @@ class Terminal:
         if cls.app_id == "" or cls.security_token == "":
             cls._warning("The `App ID` and/or `Security Token` is not set. "
                          "Get them by visiting https://www.vertopal.com")
-            cls._print("Use command vertopal config --app \"your-app-id\" "
-                       "--token \"your-security-token\" to set them."
+            cls._print("Use command :: vertopal config --app \"your-app-id\" "
+                       "--token \"your-security-token\" :: to set them."
             )
 
     @classmethod
@@ -164,12 +194,13 @@ class Terminal:
             cls._error("Input file not exists.", end="")
             cls.exit(cls.EX_INPUT_NOT_FOUND)
         except exceptions.ConnectionError:
-            cls._error("Cannot reach API endpoint "
-                      "({}). ".format(vertopal.API.ENDPOINT) +
-                      "Please check your network connection.",
-                      end="")
+            cls._error(
+                f"Cannot reach API endpoint ({vertopal.API.ENDPOINT}). "
+                "Please check your network connection.",
+                end=""
+            )
             cls.exit(cls.EX_CONNECTION_ERROR)
-        except Exception as error:
+        except Exception as error: # pylint: disable=broad-except
             cls._error(repr(error), end="")
             cls.exit(cls.EX_OTHER)
         else:
@@ -182,7 +213,7 @@ class Terminal:
                     end="",
                 )
                 cls.exit(cls.EX_INVALID_JSON_RESPONSE)
-            except Exception as error:
+            except Exception as error: # pylint: disable=broad-except
                 cls._error(repr(error), end="")
                 cls.exit(cls.EX_OTHER)
             # if http response code is 4xx or 5xx
@@ -191,10 +222,14 @@ class Terminal:
                 cls.exit(cls.EX_API_RESPONSE_ERROR)
             else:
                 if json["result"]["warning"]:
-                    cls._warning(
-                        json["result"]["warning"]["message"],
-                        json["result"]["warning"]["code"]
-                    )
+                    # Iterate over all warning messages
+                    for w_code, w_message in json["result"]["warning"].items():
+                        # Check if it's ignored in the current function call
+                        if (w_code in cls.ignore_warning and
+                                (func.__name__ in cls.ignore_warning[w_code] or
+                                cls.IGNORE_ALL in cls.ignore_warning[w_code])):
+                            continue
+                        cls._warning(w_message, w_code)
                 if json["result"]["error"]:
                     cls._error(
                         json["result"]["error"]["message"],
@@ -214,7 +249,7 @@ class Terminal:
 
         Returns:
             str: Upload task connector.
-        """        
+        """
 
         json = cls._call_task(
             vertopal.API.upload,
@@ -245,37 +280,38 @@ class Terminal:
 
         Returns:
             Optional[str]: Convert task connector or exit the program.
-        """        
+        """
 
         json = cls._call_task(
             vertopal.API.convert,
             {
-                "output": output,
+                "output_format": output,
                 "app": cls.app_id,
                 "token": cls.security_token,
                 "connector": connector,
-                "input": input_format,
+                "input_format": input_format,
                 "mode": vertopal.API.ASYNC,
             },
         )
 
         if json["entity"]["status"] == "running":
-            credits = json["entity"]["credits"]
-            cls._info("Convert credits used: {}".format(credits))
             return json["entity"]["id"]
 
         cls._error("Entity status is not running.", end="")
         cls.exit(cls.EX_OTHER)
+        return ""
 
     @classmethod
-    def _task_status(cls, connector: str) -> str:
+    def _task_status(cls, connector: str) -> SimpleNamespace:
         """Run a task response request using Vertopal API.
 
         Args:
             connector (str): Connector of a task. E.g. a convert task.
 
         Returns:
-            str: The task status.
+            SimpleNamespace: A SimpleNamespace instance with 
+                `task` (task status), `vcredits` (used vCredits), 
+                and `convert` (convert status) properties.
         """
 
         json = cls._call_task(
@@ -287,7 +323,17 @@ class Terminal:
             },
         )
 
-        return json["result"]["output"]["entity"]["status"]
+        result = json["result"]["output"]["result"]
+        if result:
+            convert_status = result["output"]["status"]
+        else:
+            convert_status = None
+
+        return SimpleNamespace(
+            task=json["result"]["output"]["entity"]["status"],
+            vcredits=json["result"]["output"]["entity"]["vcredits"],
+            convert=convert_status,
+        )
 
     @classmethod
     def _download(cls, connector: str) -> SimpleNamespace:
@@ -298,7 +344,7 @@ class Terminal:
 
         Returns:
             SimpleNamespace: A SimpleNamespace instance with `connector` and 
-                `name` properties.
+                `filename` properties.
         """
 
         json = cls._call_task(
@@ -341,11 +387,10 @@ class Terminal:
                 url=False,
             )
         except exceptions.ConnectionError:
-            cls._error("Cannot reach API endpoint "
-                      "({}). ".format(vertopal.API.ENDPOINT) +
-                      "Please check your network connection.")
+            cls._error(f"Cannot reach API endpoint ({vertopal.API.ENDPOINT}). "
+                        "Please check your network connection.")
             cls.exit(cls.EX_CONNECTION_ERROR)
-        except Exception as error:
+        except Exception as error: # pylint: disable=broad-except
             cls._error(repr(error))
             cls.exit(cls.EX_OTHER)
         else:
@@ -353,7 +398,7 @@ class Terminal:
             if (response.status_code % 1000) // 100 in (4, 5):
                 cls._error(
                     "Got an unsuccessful HTTP response code",
-                    "HTTP-RES-{}".format(response.status_code)
+                    f"HTTP-RES-{response.status_code}"
                 )
                 cls.exit(cls.EX_API_RESPONSE_ERROR)
             else:
@@ -362,7 +407,7 @@ class Terminal:
                     with open(output, 'wb') as fd:
                         for chunk in response.iter_content(chunk_size=128):
                             fd.write(chunk)
-                except Exception as error:
+                except Exception as error: # pylint: disable=broad-except
                     cls._error(repr(error))
                     cls.exit(cls.EX_FILE_WRITE_ERROR)
                 else:
@@ -395,11 +440,11 @@ class Terminal:
 
         Returns:
             None
-        """        
+        """
 
         if cls.silent:
             return
-        line = "[DONE] Your converted file saved as {}".format(str(filename))
+        line = f"[DONE] Your converted file saved as {str(filename)}"
         sys.stdout.write(line)
 
     @classmethod
@@ -416,10 +461,15 @@ class Terminal:
 
         if cls.silent:
             return
-        sys.stdout.write("[{}] {}\n".format(str(step), str(text)))
+        sys.stdout.write(f"[{str(step)}] {str(text)}\n")
 
     @classmethod
-    def _error(cls, text: str, errcode: str = None, end: str = "\n") -> None:
+    def _error(
+        cls,
+        text: str,
+        errcode: Optional[str] = None,
+        end: str = "\n"
+    ) -> None:
         """Write an error-line to the `stderr`.
 
         Args:
@@ -436,7 +486,7 @@ class Terminal:
             return
         errline = "[ERROR"
         if errcode:
-            errline += " {}] ".format(str(errcode))
+            errline += f" {str(errcode)}] "
         else:
             errline += "] "
         errline += str(text) + end
@@ -444,7 +494,7 @@ class Terminal:
         sys.stderr.write(errline)
 
     @classmethod
-    def _warning(cls, text: str, wrncode: str = None) -> None:
+    def _warning(cls, text: str, wrncode: Optional[str] = None) -> None:
         """Write a warning-line to the `strout`.
 
         Args:
@@ -459,7 +509,7 @@ class Terminal:
             return
         wrnline = "[WARNING"
         if wrncode:
-            wrnline += " {}] ".format(str(wrncode))
+            wrnline += f" {str(wrncode)}] "
         else:
             wrnline += "] "
         wrnline += str(text) + "\n"
@@ -493,7 +543,7 @@ class Terminal:
 
         Returns:
             str: Absolute path of the output file.
-        """        
+        """
 
         def get_output(filename: str) -> str:
             """Consider `Terminal.output_dir` in getting output absolute path.
@@ -503,7 +553,7 @@ class Terminal:
 
             Returns:
                 str: Absolute path of the output file.
-            """            
+            """
 
             if cls.output_dir:
                 return Path(cls.output_dir, filename).resolve()
@@ -516,11 +566,11 @@ class Terminal:
         stem = output.stem
         counter = 1
         while output.is_file() and output.exists():
-            new_name = stem + "-{}".format(counter) + Path(output).suffix
+            new_name = stem + f"-{counter}" + Path(output).suffix
             output = get_output(new_name)
             counter += 1
-        
-        return output 
+
+        return output
 
     @classmethod
     def parse(cls) -> object:
@@ -548,7 +598,7 @@ class Terminal:
             metavar="",
             help=""
         )
-        
+
         # Create the parser for the <convert> command
         parser_convert = subparsers.add_parser(
             "convert",
@@ -616,7 +666,7 @@ class Terminal:
         option = parser.add_argument_group("options")
         option.add_argument("-v", "--version",
             action="version",
-            version="vertopal version {}".format(vertopal.__version__),
+            version=f"vertopal version {vertopal.__version__}",
             help="output version information and exit"
         )
         option.add_argument("-h", "--help",
